package com.perforce.hwsclient.models;

import java.util.Objects;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.util.*;
import java.util.Date;

import com.google.gson.annotations.SerializedName;




/**
 * Detailed information about each file, as provided by the `p4 fstat` command.
 **/
@ApiModel(description = "Detailed information about each file, as provided by the `p4 fstat` command.")
public class FstatCommand   {
  
  @SerializedName("depotFile")
  private String depotFile = null;
  
  @SerializedName("movedFile")
  private String movedFile = null;
  
  @SerializedName("shelved")
  private String shelved = null;
  
  @SerializedName("headAction")
  private String headAction = null;
  
  @SerializedName("headChange")
  private String headChange = null;
  
  @SerializedName("headRev")
  private String headRev = null;
  
  @SerializedName("headType")
  private String headType = null;
  
  @SerializedName("headCharset")
  private String headCharset = null;
  
  @SerializedName("headTime")
  private Date headTime = null;
  
  @SerializedName("headModTime")
  private Date headModTime = null;
  
  @SerializedName("movedRev")
  private String movedRev = null;
  
  @SerializedName("digest")
  private String digest = null;
  
  @SerializedName("fileSize")
  private String fileSize = null;
  
  @SerializedName("actionOwner")
  private String actionOwner = null;
  
  @SerializedName("resolved")
  private String resolved = null;
  
  @SerializedName("unresolved")
  private String unresolved = null;
  
  @SerializedName("reresolvable")
  private String reresolvable = null;
  
  @SerializedName("otherOpens")
  private List<String> otherOpens = new ArrayList<String>();
  
  @SerializedName("otherLocks")
  private List<String> otherLocks = new ArrayList<String>();
  
  @SerializedName("otherActions")
  private List<String> otherActions = new ArrayList<String>();
  
  @SerializedName("otherChanges")
  private List<String> otherChanges = new ArrayList<String>();
  
  @SerializedName("resolveActions")
  private List<String> resolveActions = new ArrayList<String>();
  
  @SerializedName("resolveBaseFiles")
  private List<String> resolveBaseFiles = new ArrayList<String>();
  
  @SerializedName("resolveBaseRevs")
  private List<String> resolveBaseRevs = new ArrayList<String>();
  
  @SerializedName("resolveFromFiles")
  private List<String> resolveFromFiles = new ArrayList<String>();
  
  @SerializedName("resolveStartFromRevs")
  private List<String> resolveStartFromRevs = new ArrayList<String>();
  
  @SerializedName("resolveEndFromRevs")
  private List<String> resolveEndFromRevs = new ArrayList<String>();
  

  
  /**
   * Depot path to file.\nFor files containing special characters, the filename is displayed containing the ASCII expression of the character’s hexadecimal value.
   **/
  @ApiModelProperty(value = "Depot path to file.\nFor files containing special characters, the filename is displayed containing the ASCII expression of the character’s hexadecimal value.")
  public String getDepotFile() {
    return depotFile;
  }
  public void setDepotFile(String depotFile) {
    this.depotFile = depotFile;
  }

  
  /**
   * Name in depot of moved to/from file.
   **/
  @ApiModelProperty(value = "Name in depot of moved to/from file.")
  public String getMovedFile() {
    return movedFile;
  }
  public void setMovedFile(String movedFile) {
    this.movedFile = movedFile;
  }

  
  /**
   * Set to `shelved` if file is shelved.
   **/
  @ApiModelProperty(value = "Set to `shelved` if file is shelved.")
  public String getShelved() {
    return shelved;
  }
  public void setShelved(String shelved) {
    this.shelved = shelved;
  }

  
  /**
   * Action taken at head revision, if in depot.\n\nOne of: add, edit, delete, branch, move/add, move/delete, integrate, import, purge, or archive.
   **/
  @ApiModelProperty(value = "Action taken at head revision, if in depot.\n\nOne of: add, edit, delete, branch, move/add, move/delete, integrate, import, purge, or archive.")
  public String getHeadAction() {
    return headAction;
  }
  public void setHeadAction(String headAction) {
    this.headAction = headAction;
  }

  
  /**
   * Head revision changelist number, if in depot.
   **/
  @ApiModelProperty(value = "Head revision changelist number, if in depot.")
  public String getHeadChange() {
    return headChange;
  }
  public void setHeadChange(String headChange) {
    this.headChange = headChange;
  }

  
  /**
   * Head revision number, if in depot.
   **/
  @ApiModelProperty(value = "Head revision number, if in depot.")
  public String getHeadRev() {
    return headRev;
  }
  public void setHeadRev(String headRev) {
    this.headRev = headRev;
  }

  
  /**
   * Head revision type, if in depot.
   **/
  @ApiModelProperty(value = "Head revision type, if in depot.")
  public String getHeadType() {
    return headType;
  }
  public void setHeadType(String headType) {
    this.headType = headType;
  }

  
  /**
   * Head charset, for unicode files.
   **/
  @ApiModelProperty(value = "Head charset, for unicode files.")
  public String getHeadCharset() {
    return headCharset;
  }
  public void setHeadCharset(String headCharset) {
    this.headCharset = headCharset;
  }

  
  /**
   * Head revision changelist time, if in depot.\nTime is measured in seconds since 00:00:00 UTC, January 1, 1970.
   **/
  @ApiModelProperty(value = "Head revision changelist time, if in depot.\nTime is measured in seconds since 00:00:00 UTC, January 1, 1970.")
  public Date getHeadTime() {
    return headTime;
  }
  public void setHeadTime(Date headTime) {
    this.headTime = headTime;
  }

  
  /**
   * Head revision modification time (the time that the file was last modified on the client before submit), if in depot.
   **/
  @ApiModelProperty(value = "Head revision modification time (the time that the file was last modified on the client before submit), if in depot.")
  public Date getHeadModTime() {
    return headModTime;
  }
  public void setHeadModTime(Date headModTime) {
    this.headModTime = headModTime;
  }

  
  /**
   * Head revision of moved file.
   **/
  @ApiModelProperty(value = "Head revision of moved file.")
  public String getMovedRev() {
    return movedRev;
  }
  public void setMovedRev(String movedRev) {
    this.movedRev = movedRev;
  }

  
  /**
   * MD5 digest of a file.
   **/
  @ApiModelProperty(value = "MD5 digest of a file.")
  public String getDigest() {
    return digest;
  }
  public void setDigest(String digest) {
    this.digest = digest;
  }

  
  /**
   * File length in bytes.
   **/
  @ApiModelProperty(value = "File length in bytes.")
  public String getFileSize() {
    return fileSize;
  }
  public void setFileSize(String fileSize) {
    this.fileSize = fileSize;
  }

  
  /**
   * User who opened the file, if open.
   **/
  @ApiModelProperty(value = "User who opened the file, if open.")
  public String getActionOwner() {
    return actionOwner;
  }
  public void setActionOwner(String actionOwner) {
    this.actionOwner = actionOwner;
  }

  
  /**
   * The number, if any, of resovled integration records.
   **/
  @ApiModelProperty(value = "The number, if any, of resovled integration records.")
  public String getResolved() {
    return resolved;
  }
  public void setResolved(String resolved) {
    this.resolved = resolved;
  }

  
  /**
   * The number, if any, of unresolved integration records.
   **/
  @ApiModelProperty(value = "The number, if any, of unresolved integration records.")
  public String getUnresolved() {
    return unresolved;
  }
  public void setUnresolved(String unresolved) {
    this.unresolved = unresolved;
  }

  
  /**
   * The number, if any, of re-resolvable integration records.
   **/
  @ApiModelProperty(value = "The number, if any, of re-resolvable integration records.")
  public String getReresolvable() {
    return reresolvable;
  }
  public void setReresolvable(String reresolvable) {
    this.reresolvable = reresolvable;
  }

  
  /**
   * For each user with the file open, the workspace and user with the open file.
   **/
  @ApiModelProperty(value = "For each user with the file open, the workspace and user with the open file.")
  public List<String> getOtherOpens() {
    return otherOpens;
  }
  public void setOtherOpens(List<String> otherOpens) {
    this.otherOpens = otherOpens;
  }

  
  /**
   * For each user with the file locked, the workspace and user holding the lock.
   **/
  @ApiModelProperty(value = "For each user with the file locked, the workspace and user holding the lock.")
  public List<String> getOtherLocks() {
    return otherLocks;
  }
  public void setOtherLocks(List<String> otherLocks) {
    this.otherLocks = otherLocks;
  }

  
  /**
   * For each user with the file open, the action taken.
   **/
  @ApiModelProperty(value = "For each user with the file open, the action taken.")
  public List<String> getOtherActions() {
    return otherActions;
  }
  public void setOtherActions(List<String> otherActions) {
    this.otherActions = otherActions;
  }

  
  /**
   * The changelist number with this file open.
   **/
  @ApiModelProperty(value = "The changelist number with this file open.")
  public List<String> getOtherChanges() {
    return otherChanges;
  }
  public void setOtherChanges(List<String> otherChanges) {
    this.otherChanges = otherChanges;
  }

  
  /**
   * Pending integration action.
   **/
  @ApiModelProperty(value = "Pending integration action.")
  public List<String> getResolveActions() {
    return resolveActions;
  }
  public void setResolveActions(List<String> resolveActions) {
    this.resolveActions = resolveActions;
  }

  
  /**
   * Pending base files.
   **/
  @ApiModelProperty(value = "Pending base files.")
  public List<String> getResolveBaseFiles() {
    return resolveBaseFiles;
  }
  public void setResolveBaseFiles(List<String> resolveBaseFiles) {
    this.resolveBaseFiles = resolveBaseFiles;
  }

  
  /**
   * Pending base revision numbers.
   **/
  @ApiModelProperty(value = "Pending base revision numbers.")
  public List<String> getResolveBaseRevs() {
    return resolveBaseRevs;
  }
  public void setResolveBaseRevs(List<String> resolveBaseRevs) {
    this.resolveBaseRevs = resolveBaseRevs;
  }

  
  /**
   * Pending from files.
   **/
  @ApiModelProperty(value = "Pending from files.")
  public List<String> getResolveFromFiles() {
    return resolveFromFiles;
  }
  public void setResolveFromFiles(List<String> resolveFromFiles) {
    this.resolveFromFiles = resolveFromFiles;
  }

  
  /**
   * Pending starting revisions.
   **/
  @ApiModelProperty(value = "Pending starting revisions.")
  public List<String> getResolveStartFromRevs() {
    return resolveStartFromRevs;
  }
  public void setResolveStartFromRevs(List<String> resolveStartFromRevs) {
    this.resolveStartFromRevs = resolveStartFromRevs;
  }

  
  /**
   * Pending ending revisions.
   **/
  @ApiModelProperty(value = "Pending ending revisions.")
  public List<String> getResolveEndFromRevs() {
    return resolveEndFromRevs;
  }
  public void setResolveEndFromRevs(List<String> resolveEndFromRevs) {
    this.resolveEndFromRevs = resolveEndFromRevs;
  }

  

  @Override
  public boolean equals(Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    FstatCommand fstatCommand = (FstatCommand) o;
    return Objects.equals(this.depotFile, fstatCommand.depotFile) &&
        Objects.equals(this.movedFile, fstatCommand.movedFile) &&
        Objects.equals(this.shelved, fstatCommand.shelved) &&
        Objects.equals(this.headAction, fstatCommand.headAction) &&
        Objects.equals(this.headChange, fstatCommand.headChange) &&
        Objects.equals(this.headRev, fstatCommand.headRev) &&
        Objects.equals(this.headType, fstatCommand.headType) &&
        Objects.equals(this.headCharset, fstatCommand.headCharset) &&
        Objects.equals(this.headTime, fstatCommand.headTime) &&
        Objects.equals(this.headModTime, fstatCommand.headModTime) &&
        Objects.equals(this.movedRev, fstatCommand.movedRev) &&
        Objects.equals(this.digest, fstatCommand.digest) &&
        Objects.equals(this.fileSize, fstatCommand.fileSize) &&
        Objects.equals(this.actionOwner, fstatCommand.actionOwner) &&
        Objects.equals(this.resolved, fstatCommand.resolved) &&
        Objects.equals(this.unresolved, fstatCommand.unresolved) &&
        Objects.equals(this.reresolvable, fstatCommand.reresolvable) &&
        Objects.equals(this.otherOpens, fstatCommand.otherOpens) &&
        Objects.equals(this.otherLocks, fstatCommand.otherLocks) &&
        Objects.equals(this.otherActions, fstatCommand.otherActions) &&
        Objects.equals(this.otherChanges, fstatCommand.otherChanges) &&
        Objects.equals(this.resolveActions, fstatCommand.resolveActions) &&
        Objects.equals(this.resolveBaseFiles, fstatCommand.resolveBaseFiles) &&
        Objects.equals(this.resolveBaseRevs, fstatCommand.resolveBaseRevs) &&
        Objects.equals(this.resolveFromFiles, fstatCommand.resolveFromFiles) &&
        Objects.equals(this.resolveStartFromRevs, fstatCommand.resolveStartFromRevs) &&
        Objects.equals(this.resolveEndFromRevs, fstatCommand.resolveEndFromRevs);
  }

  @Override
  public int hashCode() {
    return Objects.hash(depotFile, movedFile, shelved, headAction, headChange, headRev, headType, headCharset, headTime, headModTime, movedRev, digest, fileSize, actionOwner, resolved, unresolved, reresolvable, otherOpens, otherLocks, otherActions, otherChanges, resolveActions, resolveBaseFiles, resolveBaseRevs, resolveFromFiles, resolveStartFromRevs, resolveEndFromRevs);
  }

  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class FstatCommand {\n");
    
    sb.append("    depotFile: ").append(toIndentedString(depotFile)).append("\n");
    sb.append("    movedFile: ").append(toIndentedString(movedFile)).append("\n");
    sb.append("    shelved: ").append(toIndentedString(shelved)).append("\n");
    sb.append("    headAction: ").append(toIndentedString(headAction)).append("\n");
    sb.append("    headChange: ").append(toIndentedString(headChange)).append("\n");
    sb.append("    headRev: ").append(toIndentedString(headRev)).append("\n");
    sb.append("    headType: ").append(toIndentedString(headType)).append("\n");
    sb.append("    headCharset: ").append(toIndentedString(headCharset)).append("\n");
    sb.append("    headTime: ").append(toIndentedString(headTime)).append("\n");
    sb.append("    headModTime: ").append(toIndentedString(headModTime)).append("\n");
    sb.append("    movedRev: ").append(toIndentedString(movedRev)).append("\n");
    sb.append("    digest: ").append(toIndentedString(digest)).append("\n");
    sb.append("    fileSize: ").append(toIndentedString(fileSize)).append("\n");
    sb.append("    actionOwner: ").append(toIndentedString(actionOwner)).append("\n");
    sb.append("    resolved: ").append(toIndentedString(resolved)).append("\n");
    sb.append("    unresolved: ").append(toIndentedString(unresolved)).append("\n");
    sb.append("    reresolvable: ").append(toIndentedString(reresolvable)).append("\n");
    sb.append("    otherOpens: ").append(toIndentedString(otherOpens)).append("\n");
    sb.append("    otherLocks: ").append(toIndentedString(otherLocks)).append("\n");
    sb.append("    otherActions: ").append(toIndentedString(otherActions)).append("\n");
    sb.append("    otherChanges: ").append(toIndentedString(otherChanges)).append("\n");
    sb.append("    resolveActions: ").append(toIndentedString(resolveActions)).append("\n");
    sb.append("    resolveBaseFiles: ").append(toIndentedString(resolveBaseFiles)).append("\n");
    sb.append("    resolveBaseRevs: ").append(toIndentedString(resolveBaseRevs)).append("\n");
    sb.append("    resolveFromFiles: ").append(toIndentedString(resolveFromFiles)).append("\n");
    sb.append("    resolveStartFromRevs: ").append(toIndentedString(resolveStartFromRevs)).append("\n");
    sb.append("    resolveEndFromRevs: ").append(toIndentedString(resolveEndFromRevs)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces
   * (except the first line).
   */
  private String toIndentedString(Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }
}
