package com.perforce.hwsclient.models;

import java.util.Objects;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import com.google.gson.annotations.SerializedName;




/**
 * A list of per-repo settings that override global settings.
 **/
@ApiModel(description = "A list of per-repo settings that override global settings.")
public class GitFusionRepoGlobalOverrides   {
  
  @SerializedName("charset")
  private String charset = null;
  
  @SerializedName("depotPathRepoCreationEnable")
  private String depotPathRepoCreationEnable = null;
  
  @SerializedName("depotPathRepoCreationP4group")
  private String depotPathRepoCreationP4group = null;
  
  @SerializedName("changeOwner")
  private String changeOwner = null;
  
  @SerializedName("enableGitBranchCreation")
  private String enableGitBranchCreation = null;
  
  @SerializedName("enableSwarmReviews")
  private String enableSwarmReviews = null;
  
  @SerializedName("enableGitMergeCommits")
  private String enableGitMergeCommits = null;
  
  @SerializedName("enableGitSubmodules")
  private String enableGitSubmodules = null;
  
  @SerializedName("ignoreAuthorPermissions")
  private String ignoreAuthorPermissions = null;
  
  @SerializedName("preflightCommit")
  private String preflightCommit = null;
  
  @SerializedName("readPermissionCheck")
  private String readPermissionCheck = null;
  
  @SerializedName("gitMergeAvoidanceAfterChangeNum")
  private String gitMergeAvoidanceAfterChangeNum = null;
  
  @SerializedName("jobLookup")
  private String jobLookup = null;
  
  @SerializedName("depotBranchCreationEnable")
  private String depotBranchCreationEnable = null;
  
  @SerializedName("depotBranchCreationP4group")
  private String depotBranchCreationP4group = null;
  
  @SerializedName("depotBranchCreationDepotPath")
  private String depotBranchCreationDepotPath = null;
  
  @SerializedName("depotBranchCreationView")
  private String depotBranchCreationView = null;
  
  @SerializedName("enableGitFindCopies")
  private String enableGitFindCopies = null;
  
  @SerializedName("enableGitFindRenames")
  private String enableGitFindRenames = null;
  
  @SerializedName("enableStreamImports")
  private String enableStreamImports = null;
  
  @SerializedName("httpUrl")
  private String httpUrl = null;
  
  @SerializedName("sshUrl")
  private String sshUrl = null;
  
  @SerializedName("emailCaseSensitivity")
  private String emailCaseSensitivity = null;
  
  @SerializedName("authorSource")
  private String authorSource = null;
  
  @SerializedName("limitSpaceMb")
  private String limitSpaceMb = null;
  
  @SerializedName("limitCommitsReceived")
  private String limitCommitsReceived = null;
  
  @SerializedName("limitFilesReceived")
  private String limitFilesReceived = null;
  
  @SerializedName("limitMegabytesReceived")
  private String limitMegabytesReceived = null;
  

  
  /**
   * Defines the default Unicode setting that Git Fusion applies to new repos.\nThis setting is valid only when Git Fusion interacts with a Unicode-enabled Perforce server.\n\n(Defaults to `UTF-8`).
   **/
  @ApiModelProperty(value = "Defines the default Unicode setting that Git Fusion applies to new repos.\nThis setting is valid only when Git Fusion interacts with a Unicode-enabled Perforce server.\n\n(Defaults to `UTF-8`).")
  public String getCharset() {
    return charset;
  }
  public void setCharset(String charset) {
    this.charset = charset;
  }

  
  /**
   * Allow Git users to create new repos by pushing/pulling a git url which specifies a Perforce depot path.\nThis is similar to creating a repo from a p4 client.
   **/
  @ApiModelProperty(value = "Allow Git users to create new repos by pushing/pulling a git url which specifies a Perforce depot path.\nThis is similar to creating a repo from a p4 client.")
  public String getDepotPathRepoCreationEnable() {
    return depotPathRepoCreationEnable;
  }
  public void setDepotPathRepoCreationEnable(String depotPathRepoCreationEnable) {
    this.depotPathRepoCreationEnable = depotPathRepoCreationEnable;
  }

  
  /**
   * Restrict which authenticated Git pushers are allowed to create new repos when depot-path-repo-creation-enable is enabled.
   **/
  @ApiModelProperty(value = "Restrict which authenticated Git pushers are allowed to create new repos when depot-path-repo-creation-enable is enabled.")
  public String getDepotPathRepoCreationP4group() {
    return depotPathRepoCreationP4group;
  }
  public void setDepotPathRepoCreationP4group(String depotPathRepoCreationP4group) {
    this.depotPathRepoCreationP4group = depotPathRepoCreationP4group;
  }

  
  /**
   * Defines whether Git Fusion assigns either the Git commit author or the Git pusher as the owner of a pushed change (submit).
   **/
  @ApiModelProperty(value = "Defines whether Git Fusion assigns either the Git commit author or the Git pusher as the owner of a pushed change (submit).")
  public String getChangeOwner() {
    return changeOwner;
  }
  public void setChangeOwner(String changeOwner) {
    this.changeOwner = changeOwner;
  }

  
  /**
   * Defines whether Git Fusion creates a new branch of Perforce depot file hierarchy for each copied branch of Git workspace history, including Git task branches as Git Fusion anonymous branches.
   **/
  @ApiModelProperty(value = "Defines whether Git Fusion creates a new branch of Perforce depot file hierarchy for each copied branch of Git workspace history, including Git task branches as Git Fusion anonymous branches.")
  public String getEnableGitBranchCreation() {
    return enableGitBranchCreation;
  }
  public void setEnableGitBranchCreation(String enableGitBranchCreation) {
    this.enableGitBranchCreation = enableGitBranchCreation;
  }

  
  /**
   * Permits branch creation for Swarm reviews, even when enable-git-branch-creation is disabled.
   **/
  @ApiModelProperty(value = "Permits branch creation for Swarm reviews, even when enable-git-branch-creation is disabled.")
  public String getEnableSwarmReviews() {
    return enableSwarmReviews;
  }
  public void setEnableSwarmReviews(String enableSwarmReviews) {
    this.enableSwarmReviews = enableSwarmReviews;
  }

  
  /**
   * Defines whether Git Fusion copies merge commits and displays them in Perforce as integrations between Perforce branches.
   **/
  @ApiModelProperty(value = "Defines whether Git Fusion copies merge commits and displays them in Perforce as integrations between Perforce branches.")
  public String getEnableGitMergeCommits() {
    return enableGitMergeCommits;
  }
  public void setEnableGitMergeCommits(String enableGitMergeCommits) {
    this.enableGitMergeCommits = enableGitMergeCommits;
  }

  
  /**
   * Defines whether Git Fusion allows Git submodules to be pushed to Perforce.
   **/
  @ApiModelProperty(value = "Defines whether Git Fusion allows Git submodules to be pushed to Perforce.")
  public String getEnableGitSubmodules() {
    return enableGitSubmodules;
  }
  public void setEnableGitSubmodules(String enableGitSubmodules) {
    this.enableGitSubmodules = enableGitSubmodules;
  }

  
  /**
   * Defines whether Git Fusion evaluates both the author's and pusher's Perforce write permissions during a push or evaluates only the pusher's permissions.
   **/
  @ApiModelProperty(value = "Defines whether Git Fusion evaluates both the author's and pusher's Perforce write permissions during a push or evaluates only the pusher's permissions.")
  public String getIgnoreAuthorPermissions() {
    return ignoreAuthorPermissions;
  }
  public void setIgnoreAuthorPermissions(String ignoreAuthorPermissions) {
    this.ignoreAuthorPermissions = ignoreAuthorPermissions;
  }

  
  /**
   * Enables you to trigger pre-flight commit scripts that enforce local policy for Git pushes. This can be especially useful if you have Perforce submit triggers that could reject a push and damage the repository.
   **/
  @ApiModelProperty(value = "Enables you to trigger pre-flight commit scripts that enforce local policy for Git pushes. This can be especially useful if you have Perforce submit triggers that could reject a push and damage the repository.")
  public String getPreflightCommit() {
    return preflightCommit;
  }
  public void setPreflightCommit(String preflightCommit) {
    this.preflightCommit = preflightCommit;
  }

  
  /**
   * Enables you to require that Git clone, pull, or fetch requests check the Perforce protections table for the puller's read permission on the files being pulled.
   **/
  @ApiModelProperty(value = "Enables you to require that Git clone, pull, or fetch requests check the Perforce protections table for the puller's read permission on the files being pulled.")
  public String getReadPermissionCheck() {
    return readPermissionCheck;
  }
  public void setReadPermissionCheck(String readPermissionCheck) {
    this.readPermissionCheck = readPermissionCheck;
  }

  
  /**
   * If the Perforce service includes any changelists submitted by Git Fusion 13.2 or earlier, you can prevent unnecessary merge commits by setting this key to the number of the last changelist submitted before your site upgraded to a later version of Git Fusion.
   **/
  @ApiModelProperty(value = "If the Perforce service includes any changelists submitted by Git Fusion 13.2 or earlier, you can prevent unnecessary merge commits by setting this key to the number of the last changelist submitted before your site upgraded to a later version of Git Fusion.")
  public String getGitMergeAvoidanceAfterChangeNum() {
    return gitMergeAvoidanceAfterChangeNum;
  }
  public void setGitMergeAvoidanceAfterChangeNum(String gitMergeAvoidanceAfterChangeNum) {
    this.gitMergeAvoidanceAfterChangeNum = gitMergeAvoidanceAfterChangeNum;
  }

  
  /**
   * Set the format for entering Perforce jobs in Git commit descriptions so that they are recognized by Git Fusion and appear in Perforce changelists as fixes.\nBy default, job IDs whose string starts with \"job\" (as in job123456) are passed through to the changelist description and job field.\nUse this option if you want Git Fusion to recognize additional expressions, such as JIRA issue IDs.
   **/
  @ApiModelProperty(value = "Set the format for entering Perforce jobs in Git commit descriptions so that they are recognized by Git Fusion and appear in Perforce changelists as fixes.\nBy default, job IDs whose string starts with \"job\" (as in job123456) are passed through to the changelist description and job field.\nUse this option if you want Git Fusion to recognize additional expressions, such as JIRA issue IDs.")
  public String getJobLookup() {
    return jobLookup;
  }
  public void setJobLookup(String jobLookup) {
    this.jobLookup = jobLookup;
  }

  
  /**
   * Allow Git users to create new fully-populated depot branches within Perforce.
   **/
  @ApiModelProperty(value = "Allow Git users to create new fully-populated depot branches within Perforce.")
  public String getDepotBranchCreationEnable() {
    return depotBranchCreationEnable;
  }
  public void setDepotBranchCreationEnable(String depotBranchCreationEnable) {
    this.depotBranchCreationEnable = depotBranchCreationEnable;
  }

  
  /**
   * Restrict the authenticated Git pushers who are allowed to create new fully-populated depot branches, if depotBranchCreationEnable is enabled.
   **/
  @ApiModelProperty(value = "Restrict the authenticated Git pushers who are allowed to create new fully-populated depot branches, if depotBranchCreationEnable is enabled.")
  public String getDepotBranchCreationP4group() {
    return depotBranchCreationP4group;
  }
  public void setDepotBranchCreationP4group(String depotBranchCreationP4group) {
    this.depotBranchCreationP4group = depotBranchCreationP4group;
  }

  
  /**
   * Tell Git Fusion where to create new fully-populated depot branches, if depotBranchCreationEnable is enabled.\n\nDefault path is `//depot/[repo]/[git_branch_name]`.
   **/
  @ApiModelProperty(value = "Tell Git Fusion where to create new fully-populated depot branches, if depotBranchCreationEnable is enabled.\n\nDefault path is `//depot/[repo]/[git_branch_name]`.")
  public String getDepotBranchCreationDepotPath() {
    return depotBranchCreationDepotPath;
  }
  public void setDepotBranchCreationDepotPath(String depotBranchCreationDepotPath) {
    this.depotBranchCreationDepotPath = depotBranchCreationDepotPath;
  }

  
  /**
   * Set how the depot path set in depotBranchCreationDepotPath should appear in Git.\n\nEnter a Perforce view specification that maps Perforce depot paths (left side) to Git work tree paths (right side).\nPerforce depot paths are relative to the root set in depotBranchCreationDepotPath.\n\nThe default `... ...` maps every file under the depotBranchCreationDepotPath root to Git.\nRight side paths must match the right side for every other branch already defined within a repo.
   **/
  @ApiModelProperty(value = "Set how the depot path set in depotBranchCreationDepotPath should appear in Git.\n\nEnter a Perforce view specification that maps Perforce depot paths (left side) to Git work tree paths (right side).\nPerforce depot paths are relative to the root set in depotBranchCreationDepotPath.\n\nThe default `... ...` maps every file under the depotBranchCreationDepotPath root to Git.\nRight side paths must match the right side for every other branch already defined within a repo.")
  public String getDepotBranchCreationView() {
    return depotBranchCreationView;
  }
  public void setDepotBranchCreationView(String depotBranchCreationView) {
    this.depotBranchCreationView = depotBranchCreationView;
  }

  
  /**
   * When Git reports a copy file action, store that action in Perforce as a p4 integ.\nOften set in tandem with enableGitFindRenames.\n\nNo/Off/0%: Do not use Git's copy detection.\nTreat all possible file copy actions as p4 add actions.\n\n1%-100%: Use Git's copy detection. Value passed to git diff-tree --find-copies=n.\n\nGit Fusion also adds --find-copies-harder whenever adding --find-copies.
   **/
  @ApiModelProperty(value = "When Git reports a copy file action, store that action in Perforce as a p4 integ.\nOften set in tandem with enableGitFindRenames.\n\nNo/Off/0%: Do not use Git's copy detection.\nTreat all possible file copy actions as p4 add actions.\n\n1%-100%: Use Git's copy detection. Value passed to git diff-tree --find-copies=n.\n\nGit Fusion also adds --find-copies-harder whenever adding --find-copies.")
  public String getEnableGitFindCopies() {
    return enableGitFindCopies;
  }
  public void setEnableGitFindCopies(String enableGitFindCopies) {
    this.enableGitFindCopies = enableGitFindCopies;
  }

  
  /**
   * When Git reports a rename (also called move) file action, store that in Perforce as a p4 move.\nOften set in tandem with enableGitFindCopies.\n\n`No`/`Off`/`0%`: Do not use Git's rename detection.\nTreat all possible file rename actions as independent p4 delete and p4 add actions.\n\n`1%`-`100%`: Use Git's rename detection.\nValue passed to git diff-tree --find-renames=n.
   **/
  @ApiModelProperty(value = "When Git reports a rename (also called move) file action, store that in Perforce as a p4 move.\nOften set in tandem with enableGitFindCopies.\n\n`No`/`Off`/`0%`: Do not use Git's rename detection.\nTreat all possible file rename actions as independent p4 delete and p4 add actions.\n\n`1%`-`100%`: Use Git's rename detection.\nValue passed to git diff-tree --find-renames=n.")
  public String getEnableGitFindRenames() {
    return enableGitFindRenames;
  }
  public void setEnableGitFindRenames(String enableGitFindRenames) {
    this.enableGitFindRenames = enableGitFindRenames;
  }

  
  /**
   * Enables you to convert Perforce stream import paths to Git submodules when you clone a Git Fusion repository.\nIf set to Yes, you must also set either httpUrl or sshUrl.
   **/
  @ApiModelProperty(value = "Enables you to convert Perforce stream import paths to Git submodules when you clone a Git Fusion repository.\nIf set to Yes, you must also set either httpUrl or sshUrl.")
  public String getEnableStreamImports() {
    return enableStreamImports;
  }
  public void setEnableStreamImports(String enableStreamImports) {
    this.enableStreamImports = enableStreamImports;
  }

  
  /**
   * The URL used by Git to clone a repository from Git Fusion over HTTP.\nThis property is required if you want to use Perforce stream import paths as git submodules and you use HTTP(S).
   **/
  @ApiModelProperty(value = "The URL used by Git to clone a repository from Git Fusion over HTTP.\nThis property is required if you want to use Perforce stream import paths as git submodules and you use HTTP(S).")
  public String getHttpUrl() {
    return httpUrl;
  }
  public void setHttpUrl(String httpUrl) {
    this.httpUrl = httpUrl;
  }

  
  /**
   * The \"URL\" used by Git to clone a repository from Git Fusion using SSH.\nThis property is required if you want to use Perforce stream import paths as git submodules and you use SSH.
   **/
  @ApiModelProperty(value = "The \"URL\" used by Git to clone a repository from Git Fusion using SSH.\nThis property is required if you want to use Perforce stream import paths as git submodules and you use SSH.")
  public String getSshUrl() {
    return sshUrl;
  }
  public void setSshUrl(String sshUrl) {
    this.sshUrl = sshUrl;
  }

  
  /**
   * Defines whether Git Fusion pays attention to case when matching Git user email addresses to Perforce user account email addresses during the authorization check.
   **/
  @ApiModelProperty(value = "Defines whether Git Fusion pays attention to case when matching Git user email addresses to Perforce user account email addresses during the authorization check.")
  public String getEmailCaseSensitivity() {
    return emailCaseSensitivity;
  }
  public void setEmailCaseSensitivity(String emailCaseSensitivity) {
    this.emailCaseSensitivity = emailCaseSensitivity;
  }

  
  /**
   * Defines the source that Git Fusion uses to identify the Perforce user associated with a Git push.\n\nDefaults to `git-email`.\n\nUse any one of the following values:\n\n- `git-email`: Use the email address of the Git author to look for a Perforce user account with the same email address. Git Fusion consults the p4gf_usermap file first, and if that fails to produce a match, it scans the Perforce user table.\n- `git-user`: Use the user.name field in the Git commit. This is the part of the author field before the email address.\n- `git-email-account`: Use the account portion of the Git author's email address. If the Git author's email value is `samwise@the_shire.com`, Git Fusion uses the Perforce account samwise.\n\nYou can also tell Git Fusion to iterate through multiple source types until it finds a matching Perforce account. Specify the source types in order of precedence, separated by commas. For example: git-user, git-email-account, git-email.
   **/
  @ApiModelProperty(value = "Defines the source that Git Fusion uses to identify the Perforce user associated with a Git push.\n\nDefaults to `git-email`.\n\nUse any one of the following values:\n\n- `git-email`: Use the email address of the Git author to look for a Perforce user account with the same email address. Git Fusion consults the p4gf_usermap file first, and if that fails to produce a match, it scans the Perforce user table.\n- `git-user`: Use the user.name field in the Git commit. This is the part of the author field before the email address.\n- `git-email-account`: Use the account portion of the Git author's email address. If the Git author's email value is `samwise@the_shire.com`, Git Fusion uses the Perforce account samwise.\n\nYou can also tell Git Fusion to iterate through multiple source types until it finds a matching Perforce account. Specify the source types in order of precedence, separated by commas. For example: git-user, git-email-account, git-email.")
  public String getAuthorSource() {
    return authorSource;
  }
  public void setAuthorSource(String authorSource) {
    this.authorSource = authorSource;
  }

  
  /**
   * Natural number representing the number of megabytes of disk space that can be consumed by any single repo.\nThis value does not include the spaced consumed on the Perforce server.
   **/
  @ApiModelProperty(value = "Natural number representing the number of megabytes of disk space that can be consumed by any single repo.\nThis value does not include the spaced consumed on the Perforce server.")
  public String getLimitSpaceMb() {
    return limitSpaceMb;
  }
  public void setLimitSpaceMb(String limitSpaceMb) {
    this.limitSpaceMb = limitSpaceMb;
  }

  
  /**
   * Natural number representing the maximum number of commits allowed in a single push.
   **/
  @ApiModelProperty(value = "Natural number representing the maximum number of commits allowed in a single push.")
  public String getLimitCommitsReceived() {
    return limitCommitsReceived;
  }
  public void setLimitCommitsReceived(String limitCommitsReceived) {
    this.limitCommitsReceived = limitCommitsReceived;
  }

  
  /**
   * Natural number representing the maximum number of files allowed in a single push.
   **/
  @ApiModelProperty(value = "Natural number representing the maximum number of files allowed in a single push.")
  public String getLimitFilesReceived() {
    return limitFilesReceived;
  }
  public void setLimitFilesReceived(String limitFilesReceived) {
    this.limitFilesReceived = limitFilesReceived;
  }

  
  /**
   * Natural number representing the maximum number of megabytes allowed in a single push.
   **/
  @ApiModelProperty(value = "Natural number representing the maximum number of megabytes allowed in a single push.")
  public String getLimitMegabytesReceived() {
    return limitMegabytesReceived;
  }
  public void setLimitMegabytesReceived(String limitMegabytesReceived) {
    this.limitMegabytesReceived = limitMegabytesReceived;
  }

  

  @Override
  public boolean equals(Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    GitFusionRepoGlobalOverrides gitFusionRepoGlobalOverrides = (GitFusionRepoGlobalOverrides) o;
    return Objects.equals(this.charset, gitFusionRepoGlobalOverrides.charset) &&
        Objects.equals(this.depotPathRepoCreationEnable, gitFusionRepoGlobalOverrides.depotPathRepoCreationEnable) &&
        Objects.equals(this.depotPathRepoCreationP4group, gitFusionRepoGlobalOverrides.depotPathRepoCreationP4group) &&
        Objects.equals(this.changeOwner, gitFusionRepoGlobalOverrides.changeOwner) &&
        Objects.equals(this.enableGitBranchCreation, gitFusionRepoGlobalOverrides.enableGitBranchCreation) &&
        Objects.equals(this.enableSwarmReviews, gitFusionRepoGlobalOverrides.enableSwarmReviews) &&
        Objects.equals(this.enableGitMergeCommits, gitFusionRepoGlobalOverrides.enableGitMergeCommits) &&
        Objects.equals(this.enableGitSubmodules, gitFusionRepoGlobalOverrides.enableGitSubmodules) &&
        Objects.equals(this.ignoreAuthorPermissions, gitFusionRepoGlobalOverrides.ignoreAuthorPermissions) &&
        Objects.equals(this.preflightCommit, gitFusionRepoGlobalOverrides.preflightCommit) &&
        Objects.equals(this.readPermissionCheck, gitFusionRepoGlobalOverrides.readPermissionCheck) &&
        Objects.equals(this.gitMergeAvoidanceAfterChangeNum, gitFusionRepoGlobalOverrides.gitMergeAvoidanceAfterChangeNum) &&
        Objects.equals(this.jobLookup, gitFusionRepoGlobalOverrides.jobLookup) &&
        Objects.equals(this.depotBranchCreationEnable, gitFusionRepoGlobalOverrides.depotBranchCreationEnable) &&
        Objects.equals(this.depotBranchCreationP4group, gitFusionRepoGlobalOverrides.depotBranchCreationP4group) &&
        Objects.equals(this.depotBranchCreationDepotPath, gitFusionRepoGlobalOverrides.depotBranchCreationDepotPath) &&
        Objects.equals(this.depotBranchCreationView, gitFusionRepoGlobalOverrides.depotBranchCreationView) &&
        Objects.equals(this.enableGitFindCopies, gitFusionRepoGlobalOverrides.enableGitFindCopies) &&
        Objects.equals(this.enableGitFindRenames, gitFusionRepoGlobalOverrides.enableGitFindRenames) &&
        Objects.equals(this.enableStreamImports, gitFusionRepoGlobalOverrides.enableStreamImports) &&
        Objects.equals(this.httpUrl, gitFusionRepoGlobalOverrides.httpUrl) &&
        Objects.equals(this.sshUrl, gitFusionRepoGlobalOverrides.sshUrl) &&
        Objects.equals(this.emailCaseSensitivity, gitFusionRepoGlobalOverrides.emailCaseSensitivity) &&
        Objects.equals(this.authorSource, gitFusionRepoGlobalOverrides.authorSource) &&
        Objects.equals(this.limitSpaceMb, gitFusionRepoGlobalOverrides.limitSpaceMb) &&
        Objects.equals(this.limitCommitsReceived, gitFusionRepoGlobalOverrides.limitCommitsReceived) &&
        Objects.equals(this.limitFilesReceived, gitFusionRepoGlobalOverrides.limitFilesReceived) &&
        Objects.equals(this.limitMegabytesReceived, gitFusionRepoGlobalOverrides.limitMegabytesReceived);
  }

  @Override
  public int hashCode() {
    return Objects.hash(charset, depotPathRepoCreationEnable, depotPathRepoCreationP4group, changeOwner, enableGitBranchCreation, enableSwarmReviews, enableGitMergeCommits, enableGitSubmodules, ignoreAuthorPermissions, preflightCommit, readPermissionCheck, gitMergeAvoidanceAfterChangeNum, jobLookup, depotBranchCreationEnable, depotBranchCreationP4group, depotBranchCreationDepotPath, depotBranchCreationView, enableGitFindCopies, enableGitFindRenames, enableStreamImports, httpUrl, sshUrl, emailCaseSensitivity, authorSource, limitSpaceMb, limitCommitsReceived, limitFilesReceived, limitMegabytesReceived);
  }

  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class GitFusionRepoGlobalOverrides {\n");
    
    sb.append("    charset: ").append(toIndentedString(charset)).append("\n");
    sb.append("    depotPathRepoCreationEnable: ").append(toIndentedString(depotPathRepoCreationEnable)).append("\n");
    sb.append("    depotPathRepoCreationP4group: ").append(toIndentedString(depotPathRepoCreationP4group)).append("\n");
    sb.append("    changeOwner: ").append(toIndentedString(changeOwner)).append("\n");
    sb.append("    enableGitBranchCreation: ").append(toIndentedString(enableGitBranchCreation)).append("\n");
    sb.append("    enableSwarmReviews: ").append(toIndentedString(enableSwarmReviews)).append("\n");
    sb.append("    enableGitMergeCommits: ").append(toIndentedString(enableGitMergeCommits)).append("\n");
    sb.append("    enableGitSubmodules: ").append(toIndentedString(enableGitSubmodules)).append("\n");
    sb.append("    ignoreAuthorPermissions: ").append(toIndentedString(ignoreAuthorPermissions)).append("\n");
    sb.append("    preflightCommit: ").append(toIndentedString(preflightCommit)).append("\n");
    sb.append("    readPermissionCheck: ").append(toIndentedString(readPermissionCheck)).append("\n");
    sb.append("    gitMergeAvoidanceAfterChangeNum: ").append(toIndentedString(gitMergeAvoidanceAfterChangeNum)).append("\n");
    sb.append("    jobLookup: ").append(toIndentedString(jobLookup)).append("\n");
    sb.append("    depotBranchCreationEnable: ").append(toIndentedString(depotBranchCreationEnable)).append("\n");
    sb.append("    depotBranchCreationP4group: ").append(toIndentedString(depotBranchCreationP4group)).append("\n");
    sb.append("    depotBranchCreationDepotPath: ").append(toIndentedString(depotBranchCreationDepotPath)).append("\n");
    sb.append("    depotBranchCreationView: ").append(toIndentedString(depotBranchCreationView)).append("\n");
    sb.append("    enableGitFindCopies: ").append(toIndentedString(enableGitFindCopies)).append("\n");
    sb.append("    enableGitFindRenames: ").append(toIndentedString(enableGitFindRenames)).append("\n");
    sb.append("    enableStreamImports: ").append(toIndentedString(enableStreamImports)).append("\n");
    sb.append("    httpUrl: ").append(toIndentedString(httpUrl)).append("\n");
    sb.append("    sshUrl: ").append(toIndentedString(sshUrl)).append("\n");
    sb.append("    emailCaseSensitivity: ").append(toIndentedString(emailCaseSensitivity)).append("\n");
    sb.append("    authorSource: ").append(toIndentedString(authorSource)).append("\n");
    sb.append("    limitSpaceMb: ").append(toIndentedString(limitSpaceMb)).append("\n");
    sb.append("    limitCommitsReceived: ").append(toIndentedString(limitCommitsReceived)).append("\n");
    sb.append("    limitFilesReceived: ").append(toIndentedString(limitFilesReceived)).append("\n");
    sb.append("    limitMegabytesReceived: ").append(toIndentedString(limitMegabytesReceived)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces
   * (except the first line).
   */
  private String toIndentedString(Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }
}
