package com.perforce.hwsclient.models;

import java.util.Objects;
import com.perforce.hwsclient.models.DepotsCommand;
import com.perforce.hwsclient.models.DirsCommand;
import com.perforce.hwsclient.models.FilesCommand;
import com.perforce.hwsclient.models.FstatCommand;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import com.google.gson.annotations.SerializedName;




/**
 * A consolidated mechanism for identifying something that generally has a path in the system.\n\nEach location references either a depot, a dir, or a file.
 **/
@ApiModel(description = "A consolidated mechanism for identifying something that generally has a path in the system.\n\nEach location references either a depot, a dir, or a file.")
public class Location   {
  
  @SerializedName("depotPath")
  private String depotPath = null;
  
  @SerializedName("depot")
  private DepotsCommand depot = null;
  
  @SerializedName("dir")
  private DirsCommand dir = null;
  
  @SerializedName("file")
  private FilesCommand file = null;
  
  @SerializedName("fstat")
  private FstatCommand fstat = null;
  
  @SerializedName("content")
  private String content = null;
  

  
  /**
   * An absolute depot path specification.
   **/
  @ApiModelProperty(value = "An absolute depot path specification.")
  public String getDepotPath() {
    return depotPath;
  }
  public void setDepotPath(String depotPath) {
    this.depotPath = depotPath;
  }

  
  /**
   **/
  @ApiModelProperty(value = "")
  public DepotsCommand getDepot() {
    return depot;
  }
  public void setDepot(DepotsCommand depot) {
    this.depot = depot;
  }

  
  /**
   **/
  @ApiModelProperty(value = "")
  public DirsCommand getDir() {
    return dir;
  }
  public void setDir(DirsCommand dir) {
    this.dir = dir;
  }

  
  /**
   **/
  @ApiModelProperty(value = "")
  public FilesCommand getFile() {
    return file;
  }
  public void setFile(FilesCommand file) {
    this.file = file;
  }

  
  /**
   **/
  @ApiModelProperty(value = "")
  public FstatCommand getFstat() {
    return fstat;
  }
  public void setFstat(FstatCommand fstat) {
    this.fstat = fstat;
  }

  
  /**
   * If this location indicates a single file, this can be set with the Base64-encoded content of the file.
   **/
  @ApiModelProperty(value = "If this location indicates a single file, this can be set with the Base64-encoded content of the file.")
  public String getContent() {
    return content;
  }
  public void setContent(String content) {
    this.content = content;
  }

  

  @Override
  public boolean equals(Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    Location location = (Location) o;
    return Objects.equals(this.depotPath, location.depotPath) &&
        Objects.equals(this.depot, location.depot) &&
        Objects.equals(this.dir, location.dir) &&
        Objects.equals(this.file, location.file) &&
        Objects.equals(this.fstat, location.fstat) &&
        Objects.equals(this.content, location.content);
  }

  @Override
  public int hashCode() {
    return Objects.hash(depotPath, depot, dir, file, fstat, content);
  }

  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class Location {\n");
    
    sb.append("    depotPath: ").append(toIndentedString(depotPath)).append("\n");
    sb.append("    depot: ").append(toIndentedString(depot)).append("\n");
    sb.append("    dir: ").append(toIndentedString(dir)).append("\n");
    sb.append("    file: ").append(toIndentedString(file)).append("\n");
    sb.append("    fstat: ").append(toIndentedString(fstat)).append("\n");
    sb.append("    content: ").append(toIndentedString(content)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces
   * (except the first line).
   */
  private String toIndentedString(Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }
}
